@@ -19,6 +19,9 @@
 #include "ibam.hpp"
 #include <getopt.h>
 
+#include <sys/stat.h>  // for mkdir
+#include <sys/types.h> // for mkdir
+
 int no_HMS=0;
 
 class HMS
@@ -63,6 +66,8 @@ int main(int argc,char *argv[])
    int   show_profile_logging=0;
    int   show_credits=0;
    int   do_second_correction=0;
+   int   show_soft_low_limit=0;
+   int   show_hard_low_limit=0;
    
    int   readonly = 0;
    
@@ -100,6 +105,8 @@ int main(int argc,char *argv[])
          {"profile",0,0,15},
          {"noprofile",0,0,16},
          {"credits",0,0,17},
+         {"softlowlimit",optional_argument,0,18},
+         {"hardlowlimit",optional_argument,0,19},
          {0,0,0,0}         
       };
       int c=getopt_long(argc,argv,"avbhcsr",long_options,&option_index);
@@ -225,11 +232,11 @@ int main(int argc,char *argv[])
          case 'b': show_bios=1; break;
          case 's': no_HMS=1; break;
          case 'r': readonly=1; break;
-         case 'a': show_profile_logging=show_seconds_left_battery_bios=show_seconds_left_battery=show_seconds_left_battery_adaptive=show_percent_battery_bios=show_percent_battery=show_seconds_left_charge=show_seconds_left_charge_adaptive=show_percent_charge=show_seconds_battery_total=show_seconds_battery_total_adaptive=show_seconds_charge_total=show_seconds_charge_total_adaptive=1; break;
-         case 'v': cerr << "IBAM-" << VERSION << " (C) 2001-2005 Sebastian Ritterbusch" << endl; break;
+         case 'a': show_soft_low_limit=show_hard_low_limit=show_profile_logging=show_seconds_left_battery_bios=show_seconds_left_battery=show_seconds_left_battery_adaptive=show_percent_battery_bios=show_percent_battery=show_seconds_left_charge=show_seconds_left_charge_adaptive=show_percent_charge=show_seconds_battery_total=show_seconds_battery_total_adaptive=show_seconds_charge_total=show_seconds_charge_total_adaptive=1; break;
+         case 'v': cerr << "IBAM-" << IBAM_VERSION << " (C) 2001-2008 Sebastian Ritterbusch" << endl; break;
          case 'h': 
-            cout << "IBAM-" << VERSION << ", the Intelligent Battery Monitor" << endl;
-            cout << "(C) 2001-2005 Sebastian Ritterbusch" << endl << endl;
+            cout << "IBAM-" << IBAM_VERSION << ", the Intelligent Battery Monitor" << endl;
+            cout << "(C) 2001-2008 Sebastian Ritterbusch" << endl << endl;
             cout << "Usage: ibam [options]" << endl;
             cout << endl;
             cout << "Options:" << endl;
@@ -252,6 +259,10 @@ int main(int argc,char *argv[])
             cout << "       --totalbatteryadaptive show adaptive total battery" << endl;
             cout << "       --totalcharge          show total charge time" << endl;
             cout << "       --totalchargeadaptive  show adaptive total charge" << endl;
+            cout << "       --hardlowlimit[=lim]   show user defined hard lower percentage limit" << endl;
+            cout << "                              [and set it to value <lim> or disable <0> it]" << endl;
+            cout << "       --softlowlimit[=lim]   show automatic lower percentage limit" << endl;
+            cout << "                              [and lower it to value <lim> or diable <0> it]" << endl;
             cout << "       --plot[=profiles]      use gnuplot to plot battery and charge graphs" << endl;
             cout << "                              and plot the last <profiles> additional profiles" << endl; 
             cout << "       --plotderivations[=profiles] same as above plus standard derivations" << endl;
@@ -261,6 +272,22 @@ int main(int argc,char *argv[])
             cout << "       --credits              to everyone contributing to ibam"<<endl;
             cout << endl;
             break;
+         case 18:
+            show_soft_low_limit=1;
+            if (optarg)
+            {
+               int n=atoi(optarg);
+               data.set_soft_low_limit(n);
+            } 
+            break;
+         case 19:
+            show_hard_low_limit=1;
+            if (optarg)
+            {
+               int n=atoi(optarg);
+               data.set_hard_low_limit(n);
+            } 
+            break;
       }
    };
 
@@ -295,16 +322,22 @@ int main(int argc,char *argv[])
    }
    
    if(show_percent_battery_bios)
-      cout << "Bios:                       " << data.percent_battery_bios() << " %" << endl;
+      cout << "Bios percentage:            " << data.percent_battery_bios() << " %" << endl;
    
    if(show_percent_battery)
       cout << "Battery percentage:         " << data.percent_battery() << " %" << endl;      
    
+   if(show_soft_low_limit && data.get_soft_low_limit()>0)
+      cout << "Soft low percentage limit:  " << data.get_soft_low_limit() << " %" << endl;      
+   
+   if(show_hard_low_limit && data.get_hard_low_limit()>0)
+      cout << "Hard low percentage limit:  " << data.get_hard_low_limit() << " %" << endl;      
+   
    if(show_percent_charge)
       cout << "Charge percentage:          " << data.percent_charge() << " %" << endl;      
    
    if(show_seconds_left_battery_bios && data.seconds_left_battery_bios()>=0)
-      cout << "Bios:                       " << HMS(data.seconds_left_battery_bios()) << endl;
+      cout << "Bios time left:             " << HMS(data.seconds_left_battery_bios()) << endl;
       
    if(show_seconds_left_battery && !do_second_correction)
       cout << "Battery time left:          " << HMS(data.seconds_left_battery()) << endl;
@@ -316,7 +349,7 @@ int main(int argc,char *argv[])
       cout << "Adapted battery time left:  " << HMS(data.seconds_left_battery_adaptive()) << endl;
 
    if(show_seconds_left_battery_adaptive && do_second_correction)
-      cout << "Adapted battery time left:  " << HMS(data.seconds_left_battery_adaptive()+data.seconds_battery_correction()) << endl;
+      cout << "Adapted battery time left:  " << HMS(data.seconds_left_battery_adaptive()+data.seconds_battery_correction_adaptive()) << endl;
 
    if(show_seconds_left_charge && !do_second_correction)
       cout << "Charge time left:           " << HMS(data.seconds_left_charge()) << endl;
@@ -328,7 +361,7 @@ int main(int argc,char *argv[])
       cout << "Adapted charge time left:   " << HMS(data.seconds_left_charge_adaptive()) << endl;
 
    if(show_seconds_left_charge_adaptive && do_second_correction)
-      cout << "Adapted charge time left:   " << HMS(data.seconds_left_charge_adaptive()+data.seconds_charge_correction()) << endl;
+      cout << "Adapted charge time left:   " << HMS(data.seconds_left_charge_adaptive()+data.seconds_charge_correction_adaptive()) << endl;
 
    if(show_seconds_battery_total)
       cout << "Total battery time:         " << HMS(data.seconds_battery_total()) << endl;
@@ -365,6 +398,9 @@ int main(int argc,char *argv[])
       cout << "Misha Nasledov          for the gkrellm2-patch" << endl;
       cout << "Matthew Richardson      for the gentoo support" << endl;
       cout << "Florian Ragwitz         for the PMU support" << endl;
+      cout << "Matthias Grimm          for the extended PMU support and pbbuttons.berlios.de" << endl;
+      cout << "Peter Gaal              for testing and the APM bugfix" << endl;
+      cout << "Brad Sawatzky           for the same APM bugfix" << endl;
    }
       
    return 0;
